abacusai.api_key — AbacusAI documentation

# abacusai.api_key

## Classes

`ApiKey` | An API Key to authenticate requests to the Abacus.AI API

## Module Contents

class abacusai.api_key.ApiKey(client, apiKeyId=None, apiKey=None, apiKeySuffix=None, tag=None, type=None, createdAt=None, expiresAt=None, isExpired=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  An API Key to authenticate requests to the Abacus.AI API

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - apiKeyId (str) – The unique ID for the API key

    - apiKey (str) – The unique API key scoped to a specific organization. Value will be partially obscured.

    - apiKeySuffix (str) – The last 4 characters of the API key.

    - tag (str) – A user-friendly tag for the API key.

    - type (str) – The type of the API key, either ‘default’, ‘code-llm’, or ‘computer-use’.

    - createdAt (str) – The timestamp when the API key was created.

    - expiresAt (str) – The timestamp when the API key will expire.

    - isExpired (bool) – Whether the API key has expired.

  api_key_id = None
  api_key = None
  api_key_suffix = None
  tag = None
  type = None
  created_at = None
  expires_at = None
  is_expired = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  delete()

    Delete a specified API key.

    Parameters:

      api_key_id (str) – The ID of the API key to delete.